# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 1.2.0 - 2024-03-05

### Added

- Make log level configurable in app settings.
- Add `post_versions` table for tracking post history.
- Expose ability to update and delete posts from JSON API.

## 1.1.0 - 2024-02-13

### Added

- Add JSON API endpoints for handling bulletin posts.

### Fixed

- Constrain the value length of input credentials.

## 1.0.0 - 2024-02-12

### Added

- Add CLI for user management and running the application.
- Add JSON API endpoints for authenticating users with JWT.
